@@ -7,7 +7,7 @@ extends 'App::Sandy::CLI::Command';
 
 with 'App::Sandy::Role::Digest';
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 sub default_opt {
 	'paired-end-id'     => '%i.%U:%c %U',
@@ -37,7 +37,7 @@ sub rm_opt {
 	'strand-bias',
 	'coverage',
 	'seqid-weight',
-	'structural-variation'
+	'genomic-variation'
 }
 
 __END__
@@ -52,7 +52,7 @@ App::Sandy::Command::Transcriptome - simulate command class. Simulate transcript
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -189,9 +189,9 @@ B<Common escape characters>
 	 %n           read end position
 	 %a           read start position regarding reference genome ***
 	 %b           read end position regarding reference genome ***
-	 %v           structural variation position ***
+	 %v           genomic variation position ***
 	----------------------------------------------------------------------------
-	*** specific for structural variation (genome simulation only)
+	*** specific for genomic variation (genome simulation only)
 
 B<Paired-end specific escape characters>
 
@@ -212,7 +212,7 @@ B<Paired-end specific escape characters>
 	 %X           fragment start position regarding reference genome ***
 	 %Z           fragment end position regarding reference genome ***
 	----------------------------------------------------------------------------
-	*** specific for structural variation (genome simulation only)
+	*** specific for genomic variation (genome simulation only)
 
 =item B<--jobs>
 
